Applies an empirical cumulative distribution function (ECDF) to raster values, returning a raster where each cell reflects its percentile rank.
Examples
if (FALSE) { # \dontrun{
test <- cdfProb(c(1,2,3,4,5))
} # }
Applies an empirical cumulative distribution function (ECDF) to raster values, returning a raster where each cell reflects its percentile rank.
if (FALSE) { # \dontrun{
test <- cdfProb(c(1,2,3,4,5))
} # }