Skip to contents

Creates a raster where each source cell is assigned the probability of connecting to a downstream feature.

Usage

connToRaster(x, dem)

Arguments

x

A list of outputs from multiple runout simulations, each containing start_cell and prob_connect.

dem

A SpatRaster (typically the DEM used in simulation) used to define the output raster grid.

Value

A SpatRaster with probability of connectivity assigned to each source cell.

Examples

if (FALSE) { # \dontrun{
# Convert connectivity results to a raster
conn_prob <- connToRaster(sim_paths, dem)
plot(conn_prob)
} # }