Implements the PCM friction model for runout simulation.
Arguments
- mu
Numeric. Sliding friction coefficient (default: 0.1).
- md
Numeric. Mass-to-drag ratio (default: 40).
- v_p
Numeric. Initial velocity (m/s) (default: 1).
- theta_p
Numeric. Slope angle of previous grid cell (degrees) (default: 30).
- theta_i
Numeric. Slope angle of current grid cell (degrees) (default: 20).
- l
Numeric. Distance between grid cells (m) (default: 12.5).
Value
Numeric. Computed velocity in the local grid cell. Returns NaN if the velocity is not physically possible (e.g., stopping condition).
Details
The PCM model calculates velocity propagation across a terrain grid based on friction, slope, and mass-to-drag ratio. It includes velocity correction for concave slope transitions as per Wichmann (2017).
References
Wichmann, V.: The Gravitational Process Path (GPP) model (v1.0) – a GIS-based simulation framework for gravitational processes, Geosci. Model Dev., 10, 3309–3327, https://doi.org/10.5194/gmd-10-3309-2017, 2017. Perla, R., Cheng, T. T., and McClung, D. M.: A Two–Parameter Model of Snow–Avalanche Motion, J. Glaciol., 26, 197–207, https://doi.org/10.3189/S002214300001073X, 1980.