Applies an empirical cumulative distribution function (ECDF) to raster values, returning a raster where each cell reflects its percentile rank.
Applies an empirical cumulative distribution function (ECDF) to raster values, returning a raster where each cell reflects its percentile rank.